@@ -1,13 +1,12 @@
 import logging
 import logging.handlers
 
-
 _logging_format = logging.Formatter(
     '%(asctime)s %(levelname)-8s  %(message)s [%(pathname)s:%(lineno)d]',
     '%Y-%m-%d %H:%M:%S')
 
 
-syslog_logging_initialized = False
+initialized_syslog_packages = []
 def init_syslog_logging(name:str = None):
     """Setup logging to be output to syslog (via /dev/log).
 
@@ -27,14 +26,14 @@ def init_syslog_logging(name:str = None):
         >>> logger = logging.getLogger('examplepkg.just.testing')
         >>> logger.critical('Just kidding, this is a test!')    
     """
-    global syslog_logging_initialized
-    if syslog_logging_initialized is False:
+    global initialized_syslog_packages
+    if name not in initialized_syslog_packages:
         syslog_handler = logging.handlers.SysLogHandler(address='/dev/log')
         _add_log_handler_with_formatter(syslog_handler, name)
-        syslog_logging_initialized = True
+        initialized_syslog_packages.append(name)
 
 
-console_logging_initialized = False
+initialized_console_packages = []
 def init_console_logging(name:str = None):
     """Setup logging to be output to the console.
 
@@ -54,11 +53,11 @@ def init_console_logging(name:str = None):
         >>> logger = logging.getLogger('examplepkg.just.testing')
         >>> logger.critical('Just kidding, this is a test!')
     """
-    global console_logging_initialized
-    if console_logging_initialized is False:
+    global initialized_console_packages
+    if name not in initialized_console_packages:
         console_handler = logging.StreamHandler()
         _add_log_handler_with_formatter(console_handler, name)
-        console_logging_initialized = True
+        initialized_syslog_packages.append(name)
 
 
 def set_logging_verbosity(verbosity_flag: int, name:str = None):
